@@ -682,7 +682,8 @@ void NetworkManagerApplet::toolTipAboutToShow()
         QString icon = "networkmanager";
         QStringList lines;
         foreach (Solid::Control::NetworkInterfaceNm09 *iface, interfaces) {
-            if (iface->connectionState() != Solid::Control::NetworkInterfaceNm09::Unavailable) {
+            if (iface->connectionState() != Solid::Control::NetworkInterfaceNm09::Unavailable &&
+                iface->connectionState() != Solid::Control::NetworkInterfaceNm09::Unmanaged) {
                 if (!lines.isEmpty()) {
                     lines << QString();
                 }
@@ -1012,7 +1013,10 @@ void NetworkManagerApplet::activatableAdded(RemoteActivatable *activatable)
     if (activatable->activatableType() == Knm::Activatable::VpnInterfaceConnection) {
         connect(ic, SIGNAL(activationStateChanged(Knm::InterfaceConnection::ActivationState,Knm::InterfaceConnection::ActivationState)),
                 this, SLOT(vpnActivationStateChanged(Knm::InterfaceConnection::ActivationState,Knm::InterfaceConnection::ActivationState)));
-        QMetaObject::invokeMethod(ic, "activationStateChanged", Q_ARG(Knm::InterfaceConnection::ActivationState, ic->oldActivationState()), Q_ARG(Knm::InterfaceConnection::ActivationState, ic->activationState()));
+	Knm::InterfaceConnection::ActivationState state = ic->activationState();
+	if (state != Knm::InterfaceConnection::Unknown) {
+            QMetaObject::invokeMethod(ic, "activationStateChanged", Q_ARG(Knm::InterfaceConnection::ActivationState, ic->oldActivationState()), Q_ARG(Knm::InterfaceConnection::ActivationState, state));
+	}
     } else if (ic) {
         connect(ic, SIGNAL(hasDefaultRouteChanged(bool)), SLOT(updateActiveInterface(bool)));
         QMetaObject::invokeMethod(ic, "hasDefaultRouteChanged", Q_ARG(bool, ic->hasDefaultRoute()));
